from typing import List

from allennlp.data.tokenizers.tokenizer import Tokenizer
from allennlp.data.tokenizers.token_class import Token
from lambo.segmenter.lambo import Lambo

class LamboTokenizer(Tokenizer):

    def __init__(self, model: str) -> None:
        self.lambo=Lambo.get(model)

    # Simple tokenisation: ignoring sentence split
    def tokenize(self, text: str) -> List[Token]:
        result=[]
        document = self.lambo.segment(text)
        for turn in document.turns:
            for sentence in turn.sentences:
                for token in sentence.tokens:
                    result.append(Token(token.text))
        return result
    
    # Full segmentation: divide into sentences and tokens
    def segment(self, text: str) -> List[List[str]]:
        result = []
        document = self.lambo.segment(text)
        for turn in document.turns:
            for sentence in turn.sentences:
                resultS=[]
                for token in sentence.tokens:
                    resultS.append(token.text)
                result.append(resultS)
        return result