"""Script to train Dependency Parsing models based on UD 2.x data."""
import pathlib

from absl import app
from absl import flags

from scripts import utils

# # ls -1 | xargs -i echo "\"{}\","
# UD 2.7
TREEBANKS = [
  "UD_Norwegian-Bokmaal",
 "UD_Norwegian-Nynorsk",
 "UD_Norwegian-NynorskLIA",
 "UD_Persian-PerDT",
 "UD_Persian-Seraji",
 "UD_Polish-LFG",
 "UD_Polish-PDB",
 "UD_Portuguese-Bosque",
 "UD_Portuguese-GSD",
 "UD_Romanian-Nonstandard",
 "UD_Romanian-RRT",
 "UD_Romanian-SiMoNERo",
 "UD_Russian-GSD",
 "UD_Russian-SynTagRus",
 "UD_Russian-Taiga",
 "UD_Serbian-SET",
 "UD_Slovak-SNK",
 "UD_Slovenian-SSJ",
 "UD_Spanish-AnCora",
 "UD_Spanish-GSD",
 "UD_Swedish-LinES",
 "UD_Swedish-Talbanken",
 # "UD_Tamil-TTB",
 "UD_Telugu-MTG",
 "UD_Turkish-Atis",
 "UD_Turkish-BOUN",
 # "UD_Turkish-FrameNet",
 "UD_Turkish-IMST",
 "UD_Turkish-Kenet",
 "UD_Turkish-Penn",
 "UD_Turkish-Tourism",
 "UD_Ukrainian-IU",
 "UD_Urdu-UDTB",
 "UD_Uyghur-UDT",
 "UD_Vietnamese-VTB",
 "UD_Welsh-CCG",
]

FLAGS = flags.FLAGS
flags.DEFINE_list(name="treebanks", default=TREEBANKS,
                  help=f"Treebanks to predict")
flags.DEFINE_string(name="data_dir", default="/tmp/lustre_shared/lukasz/UD_2.9/",
                    help="Path to UD data directory.")
flags.DEFINE_string(name="output_dir", default="/tmp/lustre_shared/lukasz/predictions_UD_29/",
                    help="Output directory for predictions")
flags.DEFINE_string(name="models_dir", default="/tmp/lustre_shared/lukasz/models_UD_2.9/",
                    help="Directory where models are stored in subfolders with the name of treebank")


def run(_):
    treebanks_dir = pathlib.Path(FLAGS.data_dir)
    for treebank in FLAGS.treebanks:
        assert treebank in TREEBANKS, f"Unknown treebank {treebank}."
        treebank_dir = treebanks_dir / treebank

        files = list(treebank_dir.iterdir())

        test_file = [f for f in files if "test" in f.name and ".conllu" in f.name]
        assert len(test_file) == 1, f"Couldn't find training file."
        test_file_path = test_file[0]

        output_path = pathlib.Path(FLAGS.output_dir) / (treebank + "predictions_test.conllu")

        model_directory = pathlib.Path(FLAGS.models_dir) / treebank
        files = list(model_directory.iterdir())
        assert len(files) == 1, f"Couldn't find model directory file."
        model_directory = model_directory / files[0]

        command = f"""
        time combo --mode predict --model_path {model_directory}
	    --input_file {test_file_path}
	    --output_file {output_path}
	    --cuda_device 0
	    --batch_size 32
	    --silent 
        """

        utils.execute_command(command)


def main():
    app.run(run)


if __name__ == "__main__":
    main()

